import numpy
import numba.unittest_support as unittest
from numba import jit
from accelerate.profiler import profile, pstats

def dot(a, b):
    sum=0
    for i in range(len(a)):
        sum += a[i]*b[i]
    return sum


class TestProfiler(unittest.TestCase):

    def test_dot(self):

        a = numpy.arange(16, dtype=numpy.float32)
        b = numpy.arange(16, dtype=numpy.float32)
        p = profile.Profile()
        p.enable()
        dot(a, b)
        p.disable()
        stats = pstats.Stats(p).strip_dirs()
        self.assertIn(('test_profiler.py', 6,
                       'dot(a:ndarray(dtype=float32, shape={shape}), b:ndarray(dtype=float32, shape={shape}))'.format(shape=str(a.shape))),
                      stats.stats)

    def test_no_signatures(self):

        a = numpy.arange(16, dtype=numpy.float32)
        b = numpy.arange(16, dtype=numpy.float32)
        p = profile.Profile(signatures=False)
        p.enable()
        dot(a, b)
        p.disable()
        stats = pstats.Stats(p).strip_dirs()
        self.assertIn(('test_profiler.py', 6, 'dot'), stats.stats)

    def test_jit(self):

        a = numpy.arange(16, dtype=numpy.float32)
        b = numpy.arange(16, dtype=numpy.float32)
        p = profile.Profile()
        cfunc = jit(nopython=True)(dot)
        p.enable()
        cfunc(a, b)
        p.disable()
        stats = pstats.Stats(p).strip_dirs()
        self.assertIn(('test_profiler.py', 6,
                       'dot(a:ndarray(dtype=float32, shape={shape}), b:ndarray(dtype=float32, shape={shape}))'.format(shape=str(a.shape))),
                      stats.stats)

    def test_runctx(self):

        a = numpy.arange(16, dtype=numpy.float32)
        b = numpy.arange(16, dtype=numpy.float32)
        p = profile.Profile(signatures=False)
        p.runctx('dot(a, b)', globals(), locals())
        stats = pstats.Stats(p).strip_dirs()
        self.assertIn(('test_profiler.py', 6, 'dot'), stats.stats)

test_cases = (TestProfiler,)

if __name__ == '__main__':
    unittest.main()

